' ========================================================================================
' GdipGetImageGraphicsContext
' ========================================================================================

' SED_PBWIN
#COMPILE EXE
#DIM ALL
#INCLUDE "GDIPLUS.INC"

' ========================================================================================
' The following example calls the GdipGetImageGraphicsContext method to create a Graphic0
' object that is associated with an Image object. The call to GdipFillEllipse does not
' paint on the display device; instead, it alters the bitmap of the Image object. The call
' to GdipDrawImage displays the altered bitmap.
' ========================================================================================
SUB GDIP_GetImageGraphicsContext (BYVAL hdc AS DWORD)

   LOCAL hStatus AS LONG
   LOCAL pGraphics AS DWORD
   LOCAL pImage AS DWORD
   LOCAL pImageGraphics AS DWORD
   LOCAL pBrush AS DWORD
   LOCAL strFileName AS STRING

   hStatus = GdipCreateFromHDC(hdc, pGraphics)

   ' // Create an Image object from a PNG file.
   strFileName = UCODE$("pattern.png")
   hStatus = GdipLoadImageFromFile(STRPTR(strFileName), pImage)

   ' // Create a Graphics object that is associated with the image.
   hStatus = GdipGetImageGraphicsContext(pImage, pImageGraphics)

   ' // Alter the image.
   hStatus = GdipCreateSolidFill(GDIP_ARGB(255, 0, 255, 0), pBrush)
   hStatus = GdipFillEllipse(pImageGraphics, pBrush, 10, 40, 100, 50)

   ' // Draw the altered image.
   hStatus = GdipDrawImage(pGraphics, pImage, 30, 20)

   ' // Cleanup
   IF pBrush THEN GdipDeleteBrush(pBrush)
   IF pImage THEN GdipDisposeImage(pImage)
   IF pImageGraphics THEN GdipDeleteGraphics(pImageGraphics)
   IF pGraphics THEN GdipDeleteGraphics(pGraphics)

END SUB
' ========================================================================================

' ========================================================================================
' Main
' ========================================================================================
FUNCTION WINMAIN (BYVAL hInstance AS DWORD, BYVAL hPrevInstance AS DWORD, BYVAL lpszCmdLine AS ASCIIZ PTR, BYVAL nCmdShow AS LONG) AS LONG

   LOCAL hr AS LONG
   LOCAL hDlg AS DWORD
   LOCAL token AS DWORD
   LOCAL StartupInput AS GdiplusStartupInput

   ' Initialize GDI+
   StartupInput.GdiplusVersion = 1
   hr = GdiplusStartup(token, StartupInput, BYVAL %NULL)
   IF hr THEN
      MSGBOX "Error initializing GDI+"
      EXIT FUNCTION
   END IF

   DIALOG NEW 0, "GdipGetImageGraphicsContext", , , 280, 210, %WS_OVERLAPPED OR %WS_THICKFRAME OR %WS_SYSMENU OR _
   %WS_MINIMIZEBOX OR %WS_MAXIMIZEBOX OR %WS_VISIBLE OR %DS_CENTER TO hDlg
   DIALOG SET COLOR hDlg, %BLACK, %WHITE
   DIALOG SHOW MODAL hDlg, CALL DlgProc

   ' Shutdown GDI+
   GdiplusShutdown token

END FUNCTION
' ========================================================================================

' ========================================================================================
' Main Dialog procedure
' ========================================================================================
CALLBACK FUNCTION DlgProc() AS LONG

   LOCAL hDC AS DWORD
   LOCAL ps AS PAINTSTRUCT

   SELECT CASE CBMSG

      CASE %WM_COMMAND
         SELECT CASE CBCTL
            CASE %IDCANCEL
               IF CBCTLMSG = %BN_CLICKED THEN DIALOG END CBHNDL, 0
         END SELECT

      CASE %WM_PAINT
         hDC = BeginPaint(CBHNDL, ps)
         GDIP_GetImageGraphicsContext hDC
         EndPaint(CBHNDL, ps)

   END SELECT

END FUNCTION
' ========================================================================================
