' ========================================================================================
' GdipGetImageGraphicsContext
' ========================================================================================

' SED_PBWIN
#COMPILE EXE
#DIM ALL
#INCLUDE "GDIPLUS.INC"

%IDC_GRAPHIC  = 101

' ========================================================================================
' The following example calls the GdipGetImageGraphicsContext method to create a Graphic0
' object that is associated with an Image object. The call to GdipFillEllipse does not
' paint on the display device; instead, it alters the bitmap of the Image object. The call
' to GdipDrawImage displays the altered bitmap.
' ========================================================================================
SUB GDIP_GetImageGraphicsContext (BYVAL hdc AS DWORD)

   LOCAL hStatus AS LONG
   LOCAL pGraphics AS DWORD
   LOCAL pImage AS DWORD
   LOCAL pImageGraphics AS DWORD
   LOCAL pBrush AS DWORD
   LOCAL strFileName AS STRING

   hStatus = GdipCreateFromHDC(hdc, pGraphics)

   ' // Create an Image object from a PNG file.
   strFileName = UCODE$("pattern.png")
   hStatus = GdipLoadImageFromFile(STRPTR(strFileName), pImage)

   ' // Create a Graphics object that is associated with the image.
   hStatus = GdipGetImageGraphicsContext(pImage, pImageGraphics)

   ' // Alter the image.
   hStatus = GdipCreateSolidFill(GDIP_ARGB(255, 0, 255, 0), pBrush)
   hStatus = GdipFillEllipse(pImageGraphics, pBrush, 10, 40, 100, 50)

   ' // Draw the altered image.
   hStatus = GdipDrawImage(pGraphics, pImage, 30, 20)

   ' // Cleanup
   IF pBrush THEN GdipDeleteBrush(pBrush)
   IF pImage THEN GdipDisposeImage(pImage)
   IF pImageGraphics THEN GdipDeleteGraphics(pImageGraphics)
   IF pGraphics THEN GdipDeleteGraphics(pGraphics)

END SUB
' ========================================================================================

' ========================================================================================
' Main
' ========================================================================================
FUNCTION WINMAIN (BYVAL hInstance AS DWORD, BYVAL hPrevInstance AS DWORD, BYVAL lpszCmdLine AS ASCIIZ PTR, BYVAL nCmdShow AS LONG) AS LONG

   LOCAL hr AS LONG
   LOCAL hDlg AS DWORD
   LOCAL hdc AS DWORD
   LOCAL token AS DWORD
   LOCAL StartupInput AS GdiplusStartupInput

   ' Initialize GDI+
   StartupInput.GdiplusVersion = 1
   hr = GdiplusStartup(token, StartupInput, BYVAL %NULL)
   IF hr THEN
      MSGBOX "Error initializing GDI+"
      EXIT FUNCTION
   END IF

   ' Create a new dialog
   DIALOG NEW PIXELS, 0, "GdipGetImageGraphicsContext", , , 400, 310, %WS_SYSMENU TO hDlg

   ' Add a graphic control
   CONTROL ADD GRAPHIC, hDlg, %IDC_GRAPHIC,"", 0, 0, 400, 310
   ' Select the drawing target
   GRAPHIC ATTACH hDlg, %IDC_GRAPHIC
   ' Set the foreground and background color
   GRAPHIC COLOR %BLACK, %WHITE
   ' Clear the entire selected graphic window
   GRAPHIC CLEAR
   ' Retrieve the handle of the device context
   GRAPHIC GET DC TO hdc
   ' Draw the graphics
   GDIP_GetImageGraphicsContext hdc

   DIALOG SHOW MODAL hDlg, CALL DlgProc

   ' Shutdown GDI+
   GdiplusShutdown token

END FUNCTION
' ========================================================================================

' ========================================================================================
' Main Dialog procedure
' ========================================================================================
CALLBACK FUNCTION DlgProc() AS LONG

   SELECT CASE CBMSG

      CASE %WM_COMMAND
         SELECT CASE CBCTL
            CASE %IDCANCEL
               IF CBCTLMSG = %BN_CLICKED THEN DIALOG END CBHNDL, 0
         END SELECT

   END SELECT

END FUNCTION
' ========================================================================================